@@ -11,6 +11,7 @@ ENVS = {
         region="us-east-2",
         client_id="6hiktq1842ko01jmtbafd0ki87",
         pool_id="us-east-2_OhcBqdjVS",
+        domain_suffix="trainml.dev",
         api_url="api.trainml.dev",
         ws_url="api-ws.trainml.dev",
     ),
@@ -18,6 +19,7 @@ ENVS = {
         region="us-east-2",
         client_id="6hiktq1842ko01jmtbafd0ki87",
         pool_id="us-east-2_OhcBqdjVS",
+        domain_suffix="trainml.page",
         api_url="api.trainml.page",
         ws_url="api-ws.trainml.page",
     ),
@@ -25,6 +27,7 @@ ENVS = {
         region="us-east-2",
         client_id="32mc1obk9nq97iv015fnmc5eq5",
         pool_id="us-east-2_68kbvTL5p",
+        domain_suffix="trainml.ai",
         api_url="api.trainml.ai",
         ws_url="api-ws.trainml.ai",
     ),
