@@ -56,11 +56,13 @@ def create(config):
             "v100",
             "a100",
             "a6000",
+            "q4000",
         ],
         case_sensitive=False,
     ),
-    default="rtx2080ti",
+    default=["rtx3090"],
     show_default=True,
+    multiple=True,
     help="GPU type.",
 )
 @click.option(
@@ -93,19 +95,20 @@ def create(config):
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
-            "DEEPLEARNING_PY37",
+            "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_112",
+            "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY37_17",
-            "TENSORFLOW_PY38_25",
-            "TENSORFLOW_PY38_24",
-            "TENSORFLOW_PY37_23",
+            "TENSORFLOW_PY39_29",
+            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY38_26",
+            "MXNET_PY39_19",
             "MXNET_PY38_18",
-            "MXNET_PY37_16",
         ],
         case_sensitive=False,
     ),
-    default="DEEPLEARNING_PY38",
+    default="DEEPLEARNING_PY39",
     show_default=True,
     help="Job environment to use",
 )
@@ -256,7 +259,7 @@ def notebook(
         config.trainml.client.jobs.create(
             name=name,
             type="notebook",
-            gpu_type=gpu_type,
+            gpu_types=gpu_type,
             gpu_count=gpu_count,
             disk_size=disk_size,
             **options,
@@ -326,10 +329,11 @@ def notebook(
             "v100",
             "a100",
             "a6000",
+            "q4000",
         ],
         case_sensitive=False,
     ),
-    default="rtx2080ti",
+    default="rtx3090",
     show_default=True,
     help="GPU type.",
 )
@@ -381,19 +385,20 @@ def notebook(
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
-            "DEEPLEARNING_PY37",
+            "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_112",
+            "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY37_17",
-            "TENSORFLOW_PY38_25",
-            "TENSORFLOW_PY38_24",
-            "TENSORFLOW_PY37_23",
+            "TENSORFLOW_PY39_29",
+            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY38_26",
+            "MXNET_PY39_19",
             "MXNET_PY38_18",
-            "MXNET_PY37_16",
         ],
         case_sensitive=False,
     ),
-    default="DEEPLEARNING_PY38",
+    default="DEEPLEARNING_PY39",
     show_default=True,
     help="Job environment to use",
 )
@@ -622,10 +627,11 @@ def training(
             "v100",
             "a100",
             "a6000",
+            "q4000",
         ],
         case_sensitive=False,
     ),
-    default="rtx2080ti",
+    default="rtx3090",
     show_default=True,
     help="GPU type.",
 )
@@ -678,19 +684,20 @@ def training(
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
-            "DEEPLEARNING_PY37",
+            "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_112",
+            "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY37_17",
-            "TENSORFLOW_PY38_25",
-            "TENSORFLOW_PY38_24",
-            "TENSORFLOW_PY37_23",
+            "TENSORFLOW_PY39_29",
+            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY38_26",
+            "MXNET_PY39_19",
             "MXNET_PY38_18",
-            "MXNET_PY37_16",
         ],
         case_sensitive=False,
     ),
-    default="DEEPLEARNING_PY38",
+    default="DEEPLEARNING_PY39",
     show_default=True,
     help="Job environment to use",
 )
@@ -940,10 +947,11 @@ def from_json(config, attach, connect, file):
             "v100",
             "a100",
             "a6000",
+            "q4000",
         ],
         case_sensitive=False,
     ),
-    default="rtx2080ti",
+    default="rtx3090",
     show_default=True,
     help="GPU type.",
 )
@@ -960,19 +968,20 @@ def from_json(config, attach, connect, file):
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
-            "DEEPLEARNING_PY37",
+            "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_112",
+            "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "PYTORCH_PY37_17",
-            "TENSORFLOW_PY38_25",
-            "TENSORFLOW_PY38_24",
-            "TENSORFLOW_PY37_23",
+            "TENSORFLOW_PY39_29",
+            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY38_26",
+            "MXNET_PY39_19",
             "MXNET_PY38_18",
-            "MXNET_PY37_16",
         ],
         case_sensitive=False,
     ),
-    default="DEEPLEARNING_PY38",
+    default="DEEPLEARNING_PY39",
     show_default=True,
     help="Job environment to use",
 )
